@@ -2,7 +2,10 @@
 
 __author__ = 'Gareth Price'
 __email__ = 'gareth.price@warwick.ac.uk'
-__version__ = '2.3.1'
+__version__ = '2.4'
+__url__ = 'http://opendiscovery.co.uk'
+
+OD_VERSION = __version__
 
 import sys
 import os
@@ -79,8 +82,8 @@ def logHeader(message):
 
 def printHeader(message):
     if 'linux' in sys.platform:
-        print """\r   {message:<20} """.format(message=message)
-    if 'darwin' in sys.platform:
+        print """\r{message:<20} """.format(message=message)
+    elif 'darwin' in sys.platform:
         print """\r   \033[38;5;204m{message:<20}\033[0m """.format(message=message)
 
 
@@ -90,7 +93,7 @@ class ProgressBar(object):
     def __init__(self, progress, total, message, newline=True):
         if 'linux' in sys.platform:
             message = "{message:<20}".format(message=message)
-        elif 'linux' in sys.platform:
+        elif 'darwin' in sys.platform:
             message = """  \033[38;5;204m{message:<20}\033[0m """.format(message=message)
 
         import time
